@@ -25,6 +25,7 @@ import sys
 from func import new_key_req, uniq
 from calculate.lib.utils import ip as ip
 from calculate.core.datavars import DataVarsCore
+from calculate.lib.utils.files import readFile
 import urllib2 as u2
 
 if hasattr(u2, "ssl"):
@@ -141,13 +142,13 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         cert.save_pem(cert_path + '/root.crt')
 
         # add certificate in trusted
-        fd = open(cert_path + '/ca_root.crt', 'a')
         try:
-            fd.write(open(cert_path + '/root.crt', 'r').read())
+            with open(cert_path + '/root.crt', 'r') as fd_r:
+                with open(cert_path + '/ca_root.crt', 'a') as fd_w:
+                    fd_w.write(fd_r.read())
         except IOError:
             print (_('error writing to (reading from) files in directory %s')
                    % cert_path)
-        fd.close()
         print _("OK")
 
     # use self root certificate as server certificate
@@ -204,15 +205,14 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
 
         local_ip = getIpLocal()
         mac = getHwAddr()
-        data = open(cert_path + '/server.csr').read()
+        data = readFile(cert_path + '/server.csr')
         res = client.service.post_server_request(request=data, ip=local_ip,
                                                  mac=mac)
         if int(res) < 0:
             print _("This server is not enabled to sign certificates!")
             return 1
-        fc = open(cert_path + '/req_id', 'w')
-        fc.write(res)
-        fc.close()
+        with open(cert_path + '/req_id', 'w') as fc:
+            fc.write(res)
         print _("Your request ID = %s") % res
         return 0
 
@@ -222,9 +222,7 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
             print (_("request not sent or file %s deleted")
                    % (cert_path + '/req_id'))
             return 1
-        fc = open(cert_path + '/req_id', 'r')
-        req_id = fc.read()
-        fc.close()
+        req_id = readFile(cert_path + '/req_id')
 
         url = "https://%s:%d/?wsdl" % (args.root_host, port)
         print url + '\n' + _("connecting...")
@@ -239,7 +237,7 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
             print '\n' + _("Close. Connection Error.")
             return 1
 
-        request = open(cert_path + '/server.csr').read()
+        request = readFile(cert_path + '/server.csr')
         md5 = hashlib.md5()
         md5.update(request)
         md5sum = md5.hexdigest()
@@ -260,18 +258,16 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         elif cert == '4':
             print _("The request was sent from another IP.")
             return 1
-        fc = open(cert_path + '/server.crt', 'w')
-        fc.write(cert)
-        fc.close()
+        with open(cert_path + '/server.crt', 'w') as fc:
+            fc.write(cert)
         os.unlink(cert_path + '/req_id')
         print _('Certificate saved. Your certificate ID = %s') % req_id
-        fd = open(cert_path + '/ca_root.crt', 'w')
-        if ca_root:
-            fd.write(ca_root)
-        # fd.write(cert)
-        if os.path.exists(cert_path + '/ca_root.crt'):
-            fd.write(open(cert_path + '/ca_root.crt', 'r').read())
-        fd.close()
+        with open(cert_path + '/ca_root.crt', 'w') as fd:
+            if ca_root:
+                fd.write(ca_root)
+            # fd.write(cert)
+            if os.path.exists(cert_path + '/ca_root.crt'):
+                fd.write(readFile(cert_path + '/ca_root.crt'))
         return 0
 
 
@@ -283,8 +279,7 @@ def create_path(data_path, certbase, rights, group_rights, local_data_path):
             except OSError:
                 print (_("cannot create directory %s")
                        % (data_path + '/client_certs'))
-        temp = open(certbase, 'w')
-        temp.close()
+        open(certbase, 'w').close()
 
     if not os.path.exists(data_path + '/conf'):
         try:
@@ -560,7 +555,7 @@ def view_cert_info(cert, cert_id, rights, group_rights):
 
     results = []
     if not os.path.exists(group_rights):
-        open(group_rights, 'w')
+        open(group_rights, 'w').close()
 
     with open(group_rights) as fd:
         t = fd.read()
@@ -1090,11 +1085,11 @@ def revoke_signed_cert(revoke_cert_id, data_path, cert_path):
 
     index_file = CRL_db_dir + 'index'
     if not os.path.exists(index_file):
-        open(index_file, 'w')
+        open(index_file, 'w').close()
 
     serial_file = CRL_db_dir + 'serial'
     if not os.path.exists(serial_file):
-        open(serial_file, 'w')
+        open(serial_file, 'w').close()
 
     default_crl_days = 14
 
