@@ -56,8 +56,8 @@ def add_cert(mac, client_type, client_counter, client_certname,
 def get_ca(cert_path):
     import OpenSSL
 
-    server_cert = open(cert_path + '/server.crt', 'r').read()
-    ca_certs = open(cert_path + '/ca_root.crt', 'r').read()
+    server_cert = readFile(cert_path + '/server.crt', 'r')
+    ca_certs = readFile(cert_path + '/ca_root.crt', 'r')
 
     certobj = OpenSSL.crypto.load_certificate(
         OpenSSL.SSL.FILETYPE_PEM, server_cert)
